@@ -177,12 +177,12 @@ static struct button_widget button_widgets[] = {
     { GDK_f, 0 }},
 
     {FN_CLEAR,              "clear_simple",
-    { 0,          0 },
-    { GDK_Delete, 0 }},
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_Delete,     0 }},
     
     {FN_CLEAR,              "clear_advanced",
-    { 0,          0 },
-    { GDK_Delete, 0 }},
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_Delete,     0 }},
 
     {FN_SHIFT,              "shift_left",
     { 0,        0 },
@@ -1047,15 +1047,12 @@ redo_display(gpointer data)
 void
 ui_set_display(char *str, int cursor)
 {
-    char localized[MAX_LOCALIZED];
     GtkTextIter iter;
     GtkAdjustment *adj;
 
-    if (str == NULL || str[0] == '\0') {
+    // ???
+    if (str[0] == '\0') {
         str = " ";
-    } else {
-        localize_expression(localized, str, MAX_LOCALIZED, &cursor);
-        str = localized;
     }
 
     gtk_text_buffer_set_text(X.display_buffer, str, -1);
@@ -2008,7 +2005,7 @@ kframe_key_press_cb(GtkWidget *widget, GdkEventKey *event)
     }
     
     /* Delete in display */
-    if (event->keyval == GDK_Delete && state == 0) {
+    if (event->keyval == GDK_Delete && state == 0 && (event->state & GDK_SHIFT_MASK) == 0) {
         do_button(FN_DELETE, 0);
         return (TRUE);
     }
@@ -2019,14 +2016,14 @@ kframe_key_press_cb(GtkWidget *widget, GdkEventKey *event)
                                      TRUE);
         return (TRUE);
     }
-
+    
     for (i = 0; i < NBUTTONS; i++) {
         button = X.buttons[i];
         
         /* Check if function is available */
         if (!GTK_WIDGET_IS_SENSITIVE(button)) {
             continue;
-        }        
+        }
         
         /* In basic mode only allow buttons that the user can see */
         if (X.mode == BASIC &&
@@ -2037,11 +2034,13 @@ kframe_key_press_cb(GtkWidget *widget, GdkEventKey *event)
 
         // FIXME: This is a bit hacky - needs to be rethought
         for (j = 0; button_widgets[i].accelerator_keys[j] != 0; j++) {
-            if (button_widgets[i].accelerator_keys[j] == event->keyval) {
-                // A few shortcuts have modifiers
-                if (button_widgets[i].accelerator_mods[j] != 0 &&
-                    button_widgets[i].accelerator_mods[j] != state)
-                   continue;
+            if (button_widgets[i].accelerator_keys[j] == event->keyval &&
+                (button_widgets[i].accelerator_mods[j] & ~GDK_SHIFT_MASK) == state) {
+                
+                // If we use shift for this shortcut then check it was in the original mask
+                if ((button_widgets[i].accelerator_mods[j] & GDK_SHIFT_MASK) &&
+                    !(event->state & GDK_SHIFT_MASK))
+                    continue;
 
                 // Hack if this is a multi-function button
                 if (GPOINTER_TO_INT(g_object_get_data(G_OBJECT(button), "calc_function")) !=
@@ -2112,13 +2111,26 @@ get_proc(GtkClipboard *clipboard, const gchar *buffer, gpointer data)
         /* If the clipboard buffer contains any occurances of the "thousands
          * separator", remove them.
          */
-        if (*srcp == v->tsep[0]) {
-            if (strstr(srcp, v->tsep) == srcp) {
-                srcp += strlen(v->tsep) - 1;
-                continue;
-            }
+        if (v->tsep[0] != '\0' && strncmp(srcp, v->tsep, strlen(v->tsep)) == 0) {
+            srcp += strlen(v->tsep) - 1;
+            continue;
+        }
+        
+        /* Replace radix with "." */
+        else if (strncmp(srcp, v->radix, strlen(v->radix)) == 0) {
+            c = '.';
         }
 
+        /* Replace tabs with spaces */        
+        else if (*srcp == '\t') {
+            c = ' ';
+        }
+        
+        /* Terminate on newlines */        
+        else if (*srcp == '\r' || *srcp == '\n') {
+            c = '\0';
+        }
+        
         /* If an "A", "B", "C", "D" or "F" character is encountered, it 
          * will be converted to its lowercase equivalent. If an "E" is 
          * found,  and the next character is a "-" or a "+", then it 
@@ -2126,27 +2138,8 @@ get_proc(GtkClipboard *clipboard, const gchar *buffer, gpointer data)
          * exponential number), otherwise its converted to a lower case 
          * "e". See bugs #455889 and #469245 for more details.
          */
-        switch (*srcp) {
-            /* Replace tabs with spaces */
-            case '\t':
-                c = ' ';
-                break;
-                
-            /* Terminate on newlines */
-            case '\r':
-            case '\n':
-                c = '\0';
-                break;
-                
-            case 'A':
-            case 'B':
-            case 'C':
-            case 'D':
-            case 'F':
-                c = tolower(*srcp);
-                break;
-
-            case 'E':
+        else if (*srcp >= 'A' && *srcp <= 'F') {
+            if (*srcp == 'E') {
                 c = *srcp;
                 if (srcp < (end_buffer-1)) {
                     if (*(srcp+1) != '-' &&
@@ -2154,18 +2147,22 @@ get_proc(GtkClipboard *clipboard, const gchar *buffer, gpointer data)
                         c = tolower(*srcp);
                     }
                 }
-                break;
-            
-            default:
-                c = *srcp;
-                break;
+            }
+            else
+                c = tolower(*srcp);
         }
         
+        else
+            c = *srcp;
+        
         *dstp++ = c;
     }
     *dstp++ = '\0';
 
-    display_insert(&v->display, get_cursor(), (char *)text);
+    if (display_is_result(&v->display))
+        display_set_string(&v->display, (char *)text, -1);
+    else
+        display_insert(&v->display, get_cursor(), (char *)text);        
     display_set_cursor(&v->display, -1);
     free(text);
 }
@@ -2833,7 +2830,7 @@ ui_load(void)
     ui_set_show_trailing_zeroes(v->display.show_zeroes);
     
     ui_set_mode(X.mode);
-    ui_set_numeric_mode(FIX);
+    ui_set_numeric_mode(v->display.format);
     ui_set_base(v->base);
     ui_set_accuracy(v->accuracy);
     ui_set_undo_enabled(FALSE, FALSE);
