@@ -24,7 +24,16 @@
 
 #include "mp.h"
 
-void do_rcl_reg(int reg, int value[MP_SIZE]);
-void do_sto_reg(int reg, int value[MP_SIZE]);
+void register_init();
+void register_set(int index, int value[MP_SIZE]);
+void register_get(int index, int value[MP_SIZE]);
+
+void constant_set(int index, const char *name, int value[MP_SIZE]);
+const char *constant_get_name(int index);
+const int *constant_get_value(int index);
+
+void function_set(int index, const char *name, const char *value);
+const char *function_get_name(int index);
+const char *function_get_value(int index);
 
 #endif /*REGISTER_H*/
