@@ -43,7 +43,7 @@ test(char *expression, char *expected, int expected_error)
         return;
     }
     
-    mp_cast_to_string(result_str, MAXLINE, result, basevals[v->base], 100);
+    mp_cast_to_string(result_str, MAXLINE, result, basevals[v->base], 9);
     if(strcmp(result_str, expected) != 0)
         printf("FAIL: '%s' -> '%s', expected '%s'\n", expression, result_str, expected);
     else
@@ -54,8 +54,6 @@ test(char *expression, char *expected, int expected_error)
 void
 test_parser()
 {
-    v->modetype = SCIENTIFIC;
-    
     test("0", "0", 0);
     test("1", "1", 0);
     test("+1", "1", 0);
@@ -78,6 +76,7 @@ test_parser()
     test("0.001+40000", "40000.001", 0);
     test("2-3", "-1", 0);
     test("3-2", "1", 0);
+    test("1-0.9-0.1", "0", 0);   
     test("40000-0.001", "39999.999", 0);
     test("0.001-40000", "-39999.999", 0);
     test("40000000-40000000", "0", 0);
@@ -112,6 +111,12 @@ test_parser()
     test("Sqrt(4)", "2", 0);
     test("Sqrt(2)", "1.414213562", 0);
     
+    test("0 Mod 7", "0", 0);
+    test("6 Mod 7", "6", 0);
+    test("7 Mod 7", "0", 0);
+    test("8 Mod 7", "1", 0);
+    test("-1 Mod 7", "6", 0);
+    
     test("Int(3.2)", "3", 0);
     test("Frac(3.2)", "0.2", 0);
     test("Int(-3.2)", "-3", 0);
@@ -119,14 +124,25 @@ test_parser()
 
     test("Abs(1)", "1", 0);
     test("Abs(-1)", "1", 0);
+    
+    test("Ln(e^1)", "1", 0);
 
+    v->ttype = DEG;    
     test("Sin(0)", "0", 0);
     test("Sin(45) - 1/Sqrt(2)", "0", 0);
     test("Sin(20) + Sin(-20)", "0", 0);
+    test("Sin(90)", "1", 0);
+    test("Sin(180)", "0", 0);
+   
     test("Cos(0)", "1", 0);
     test("Cos(45) - 1/Sqrt(2)", "0", 0);
     test("Cos(20) - Cos(-20)", "0", 0);
+    test("Cos(90)", "0", 0);
+    test("Cos(180)", "-1", 0);
+
     test("Tan(0)", "0", 0);
+    test("Tan(10) - Sin(10)/Cos(10)", "0", 0);
+    test("Tan(90)", "", -20001);
 
     test("Acos(0)", "90", 0);
     test("Acos(1)", "0", 0);
@@ -149,7 +165,6 @@ test_parser()
     test("Tanh(0)", "0", 0);
     test("Tanh(10) - Sinh(10)/Cosh(10)", "0", 0);
 
-
     test("Atanh(0)", "0", 0);
     test("Atanh(1/10) - 1/2*Ln(11/9)", "0", 0);
 
